@@ -34,7 +34,9 @@
    D_RGB_TIMING,
    D_RGB_PERSIST,
    D_RGB_BITDIST,
+   D_RGB_OPERM,
    D_RGB_LMN,
+   D_RGB_MINIMUM_DISTANCE,
    D_STS_MONOBIT,
    D_STS_RUNS,
    D_STS_BLOCK,
